@@ -204,6 +204,36 @@ def journal(
         },
     )
 
+    # Show effective runtime models/config once at startup
+    try:
+        _provider = get_model_provider(llm_model)
+    except Exception:
+        _provider = "unknown"
+    _lines: list[str] = []
+    _lines.append(
+        f"LLM: {llm_model} (provider: {_provider}; mode={CONFIG.llm_mode}; cloud_off={CONFIG.llm_cloud_off})"
+    )
+    _lines.append(
+        f"STT: {selection.backend_id} model={selection.model} compute={selection.compute or '-'}"
+    )
+    if selection.reason:
+        _lines.append(f"STT auto-private: {selection.reason}")
+    if selection.warnings:
+        _lines.append("STT warnings: " + ", ".join(selection.warnings))
+    if CONFIG.speak_llm and CONFIG.tts_enabled:
+        _lines.append(
+            f"TTS: openai:{CONFIG.tts_model} voice={CONFIG.tts_voice} format={CONFIG.tts_format}"
+        )
+    else:
+        _lines.append("TTS: disabled")
+    console.print(
+        Panel.fit(
+            Text("\n".join(_lines)),
+            title="Runtime Models",
+            border_style="cyan",
+        )
+    )
+
     # Propagate config flag
     CONFIG.delete_wav_when_safe = bool(delete_wav_when_safe)
 
@@ -380,7 +410,7 @@ def start_or_resume_session(
             console.print(
                 Panel.fit(
                     "No prior sessions found. Starting a new session.",
-                    title="Healthy Self Journal",
+                    title="Healthyself Journal",
                     border_style="magenta",
                 )
             )
@@ -411,7 +441,7 @@ def start_or_resume_session(
                     f"Resuming session {state.session_id}. Recording starts immediately.\n"
                     "Press any key to stop. Q saves then ends after this entry.\n\n"
                     "Tip: Say 'give me a question' to get a quick prompt from the built-in examples.",
-                    title="Healthy Self Journal",
+                    title="Healthyself Journal",
                     border_style="magenta",
                 )
             )
@@ -439,7 +469,7 @@ def start_or_resume_session(
                 "Voice journaling session starting. Recording starts immediately.\n"
                 "Press any key to stop. Q saves then ends after this entry.\n\n"
                 "Tip: Say 'give me a question' to get a quick prompt from the built-in examples.",
-                title="Healthy Self Journal",
+                title="Healthyself Journal",
                 border_style="magenta",
             )
         )
@@ -695,7 +725,7 @@ def finalize_or_cleanup(*, manager: SessionManager, state, sessions_dir: Path) -
         )
         console.print(
             Panel.fit(
-                f"Session saved to {state.markdown_path.name}",
+                f"Session saved to {state.markdown_path.resolve()}",
                 title="Session Complete",
                 border_style="magenta",
             )
@@ -720,24 +750,31 @@ def build_app() -> typer.Typer:
 
     app = typer.Typer(
         add_completion=False,
-        no_args_is_help=True,
+        no_args_is_help=False,
+        invoke_without_command=True,
         context_settings={"help_option_names": ["-h", "--help"]},
-        help="Journaling interfaces (CLI and web).",
+        help=(
+            "Journaling interfaces.\n\n"
+            "Tip: run 'healthyselfjournal journal' to start the CLI interface."
+        ),
     )
 
     # Explicit subcommand for the interactive CLI loop
     app.command("cli")(journal)
 
     # Subcommand to launch the web interface
-    try:
-        from .cli_journal_web import (
-            web as web_command,
-        )  # Lazy-heavy imports are inside the function
+    import os as _os
 
-        app.command("web")(web_command)
-    except Exception:
-        # If import fails at build time (e.g., optional deps), we still allow CLI usage.
-        pass
+    if _os.environ.get("HSJ_ENABLE_WEB", "0") in {"1", "true", "yes"}:
+        try:
+            from .cli_journal_web import (
+                web as web_command,
+            )  # Lazy-heavy imports are inside the function
+
+            app.command("web")(web_command)
+        except Exception:
+            # If import fails at build time (e.g., optional deps), we still allow CLI usage.
+            pass
 
     # Subcommand to launch the desktop app (PyWebView shell)
     try:
